pub async fn suspend(function: impl FnOnce(&mut Context<'_>))Expand description
Suspend the current task until the provided function is called with a context. The function will be called with a mutable reference to the task’s context, allowing it to wake the